==> gen_pop_linkml2sheets-0.1.1.tar.gz: gen_pop_linkml2sheets-0.1.1/README.md <==
<!-- Improved compatibility of back to top link: See: https://github.com/othneildrew/Best-README-Template/pull/73 -->

<a name="readme-top"></a>

<!--
*** Thanks for checking out the Best-README-Template. If you have a suggestion
*** that would make this better, please fork the repo and create a pull request
*** or simply open an issue with the tag "enhancement".
*** Don't forget to give the project a star!
*** Thanks again! Now go create something AMAZING! :D
-->

<!-- PROJECT SHIELDS -->
<!--
*** I'm using markdown "reference style" links for readability.
*** Reference links are enclosed in brackets [ ] instead of parentheses ( ).
*** See the bottom of this document for the declaration of the reference variables
*** for contributors-url, forks-url, etc. This is an optional, concise syntax you may use.
*** https://www.markdownguide.org/basic-syntax/#reference-style-links
-->

<!-- PROJECT LOGO -->

<h1>Single step population of linkml2sheets usage reports, with useful columns only</h1>

<p>Single step population of linkml2sheets usage reports, with useful columns only</p>
<nav>
  <a href="https://github.com/turbomam/gen-pop-linkml2sheets">Repo</a>
  |
  <a href="https://github.com/turbomam/gen-pop-linkml2sheets/issues">Report Bug</a>
  |
  <a href="https://github.com/turbomam/gen-pop-linkml2sheets/releases">Releases</a>
</nav>

<!-- TABLE OF CONTENTS -->

<br><br>

<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
  </ol>
</details>
<br><br>
<!-- ABOUT THE PROJECT -->

## About The Project

[TODO]

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- GETTING STARTED -->

## Getting Started

This is a standard Python project that runs on the CLI.

### Prerequisites

- python >= 3.10 (it will probably work with lower versions, but I haven't tested it)
- poetry >= 1.2

### Installation

1. Install dependencies `> poetry install && poetry shell`
1. Install the language model `> python -m spacy download de_core_news_sm`
1. Run with [TODO]

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- USAGE EXAMPLES -->

## Usage

[TODO] Use this space to show useful examples of how a project can be used.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- ROADMAP -->

## Roadmap

- [ ] Feature 1
- [ ] Feature 2
- [ ] Feature 3
  - [ ] Nested Feature

See the [open issues](https://github.com/turbomam/gen-pop-linkml2sheets/issues) for a full list of proposed features (and known issues).

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- CONTRIBUTING -->

## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- LICENSE -->

## License

Distributed under the MIT License. See [LICENSE.md](./LICENSE.md) for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- CONTACT -->

## Contact

Fritz, [@your_name@mastodon.social](https://mastodon.social/@your_name)

Project Link: [https://github.com/gotofritz/german-learning](https://github.com/gotofritz/german-learning)

<p align="right">(<a href="#readme-top">back to top</a>)</p>

==> gen_pop_linkml2sheets-0.1.9.tar.gz: gen_pop_linkml2sheets-0.1.9/README.md <==
<!-- Improved compatibility of back to top link: See: https://github.com/othneildrew/Best-README-Template/pull/73 -->

<a name="readme-top"></a>

<!--
*** Thanks for checking out the Best-README-Template. If you have a suggestion
*** that would make this better, please fork the repo and create a pull request
*** or simply open an issue with the tag "enhancement".
*** Don't forget to give the project a star!
*** Thanks again! Now go create something AMAZING! :D
-->

<!-- PROJECT SHIELDS -->
<!--
*** I'm using markdown "reference style" links for readability.
*** Reference links are enclosed in brackets [ ] instead of parentheses ( ).
*** See the bottom of this document for the declaration of the reference variables
*** for contributors-url, forks-url, etc. This is an optional, concise syntax you may use.
*** https://www.markdownguide.org/basic-syntax/#reference-style-links
-->

<!-- PROJECT LOGO -->

<h1>Single step population of linkml2sheets usage reports, with useful columns only</h1>

<p>Single step population of linkml2sheets usage reports, with useful columns only</p>
<nav>
  <a href="https://github.com/turbomam/gen-pop-linkml2sheets">Repo</a>
  |
  <a href="https://github.com/turbomam/gen-pop-linkml2sheets/issues">Report Bug</a>
  |
  <a href="https://github.com/turbomam/gen-pop-linkml2sheets/releases">Releases</a>
</nav>

<!-- TABLE OF CONTENTS -->

<br><br>

<details>
  <summary>Table of Contents</summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
  </ol>
</details>
<br><br>
<!-- ABOUT THE PROJECT -->

## About The Project

[TODO]

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- GETTING STARTED -->

## Getting Started

This is a standard Python project that runs on the CLI.

### Prerequisites

- python >= 3.10 (it will probably work with lower versions, but I haven't tested it)
- poetry >= 1.2

### Installation

1. Install dependencies `> poetry install && poetry shell`
1. Install the language model `> python -m spacy download de_core_news_sm`
1. Run with [TODO]

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- USAGE EXAMPLES -->

## Usage

[TODO] Use this space to show useful examples of how a project can be used.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- ROADMAP -->

## Roadmap

- [ ] Feature 1
- [ ] Feature 2
- [ ] Feature 3
    - [ ] Nested Feature

See the [open issues](https://github.com/turbomam/gen-pop-linkml2sheets/issues) for a full list of proposed features (
and known issues).

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- CONTRIBUTING -->

## Contributing

Contributions are what make the open source community such an amazing place to learn, inspire, and create. Any
contributions you make are **greatly appreciated**.

If you have a suggestion that would make this better, please fork the repo and create a pull request. You can also
simply open an issue with the tag "enhancement".
Don't forget to give the project a star! Thanks again!

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- LICENSE -->

## License

Distributed under the MIT License. See [LICENSE.md](./LICENSE.md) for more information.

<p align="right">(<a href="#readme-top">back to top</a>)</p>

<!-- CONTACT -->

## Contact

Based on https://gotofritz.net/blog/creating-a-poetry-driven-python-project-template-with-cookiecutter/

Esp, `cookiecutter gh:gotofritz/cookiecutter-gotofritz-poetry`

Fritz, [@your_name@mastodon.social](https://mastodon.social/@your_name)

Project Link: [https://github.com/gotofritz/german-learning](https://github.com/gotofritz/german-learning)

<p align="right">(<a href="#readme-top">back to top</a>)</p>
